@@ -7,8 +7,8 @@
 ## it prefilters the high frequency components of the signal and
 ## avoids aliasing effects.
 ##
-## @deftypefnx {Function File} @var{y} = downsample(@var{x},@var{n},@var{phase})
-## Select every nth element starting at sample @var{phase}.
+## @deftypefnx {Function File} @var{y} = downsample(@var{x},@var{n},@var{offset})
+## Select every nth element starting at sample @var{offset}.
 ## @end deftypefn
 ## @seealso{decimate, interp, resample, upfirdn, upsample}
 
@@ -16,24 +16,24 @@
 ## This function is public domain
 
 function y = downsample(x,n,phase)
-  if nargin<2 || nargin>3, usage('downsample(x,n,[phase]'); end
-  if nargin==2, phase = 1; end
+  if nargin<2 || nargin>3, usage('downsample(x,n,[offset]'); end
+  if nargin==2, phase = 0; end
 
-  if phase > n
+  if phase > n - 1
     warning("This is incompatible with Matlab (phase = 0:n-1). See\
     octave-forge signal package release notes for details." )
   end
 
   if isvector(x)
-    y = x(phase:n:end);
+    y = x(phase + 1:n:end);
   else
-    y = x(phase:n:end,:);
+    y = x(phase + 1:n:end,:);
   end
 end
 
 %!assert(downsample([1,2,3,4,5],2),[1,3,5]);
 %!assert(downsample([1;2;3;4;5],2),[1;3;5]);
 %!assert(downsample([1,2;3,4;5,6;7,8;9,10],2),[1,2;5,6;9,10]);
-%!assert(downsample([1,2,3,4,5],2,2),[2,4]);
-%!assert(downsample([1,2;3,4;5,6;7,8;9,10],2,2),[3,4;7,8]);
+%!assert(downsample([1,2,3,4,5],2,1),[2,4]);
+%!assert(downsample([1,2;3,4;5,6;7,8;9,10],2,1),[3,4;7,8]);
 
